@@ -3,6 +3,57 @@ Currently, this package is experimental and may change in the future.
 """
 from __future__ import absolute_import
 import sys
+import importlib.util
+
+from pathlib import Path
+
+from importlib.abc import MetaPathFinder
+from importlib.machinery import ExtensionFileLoader
+
+LOADING_STACK = []
+LIB_EXTS = [".pyd", ".so"]
+
+def find_lib_path(paths, vtk_module_name):
+    for ext in LIB_EXTS:
+        for base_path in paths:
+            # vtk-wheel => vtkCommonCore.cpython-310-darwin.so
+            # paraview  => vtkCommonCore.so
+            # Caution: vtkIOXML vs vtkIOXMLParser
+            for f in Path(base_path).glob(f"{vtk_module_name}[.-]*"):
+                resolved_file = f.resolve()
+                if resolved_file.is_file() and ext in resolved_file.suffixes:
+                    return str(resolved_file)
+
+
+class VTKMetaHook(MetaPathFinder):
+    """Attach a custom  loaded for vtk native library loading to defer loading of pure python dependencies"""
+    def find_spec(self, fullname, path, target=None):
+        if fullname.startswith("vtkmodules.vtk"):
+            vtk_module_name = fullname.split(".")[1]
+            module_path = find_lib_path(path, vtk_module_name)
+            if module_path is None:
+                return None
+
+            LOADING_STACK.append(fullname)
+            return importlib.util.spec_from_file_location(fullname, module_path, loader=VTKLoader(fullname, module_path))
+
+        return None
+
+
+class VTKLoader(ExtensionFileLoader):
+    """Flush any pending dependency load once initialize() phase is done"""
+    def exec_module(self, module):
+        super().exec_module(module)
+
+        # Process pending dependencies only if the module match the first load request
+        if len(LOADING_STACK) and LOADING_STACK[0] == module.__name__:
+            LOADING_STACK.clear()
+            on_vtk_module_init_completed()
+
+
+
+# Register our hook for vtk library loader
+sys.meta_path.insert(0, VTKMetaHook())
 
 
 def _windows_dll_path():
@@ -58,7 +109,7 @@ def _load_vtkmodules_static():
 #------------------------------------------------------------------------------
 # list the contents
 __all__ = [
-    'vtkCommonCore',
+        'vtkCommonCore',
     'vtkWebCore',
     'vtkCommonMath',
     'vtkCommonTransforms',
@@ -102,8 +153,11 @@ __all__ = [
     'vtkRenderingLICOpenGL2',
     'vtkRenderingParallelLIC',
     'vtkRenderingParallel',
+    'vtkRenderingVRModels',
     'vtkRenderingMatplotlib',
     'vtkRenderingLabel',
+    'vtkChartsCore',
+    'vtkRenderingGridAxes',
     'vtkRenderingContextOpenGL2',
     'vtkRenderingCellGrid',
     'vtkParallelMPI4Py',
@@ -133,8 +187,10 @@ __all__ = [
     'vtkIOParallel',
     'vtkIOMPIImage',
     'vtkIOLAS',
+    'vtkIOLANLX3D',
     'vtkIOImport',
     'vtkIOIOSS',
+    'vtkIOHDF',
     'vtkIOH5part',
     'vtkIOH5Rage',
     'vtkIOFides',
@@ -151,13 +207,13 @@ __all__ = [
     'vtkRenderingGL2PSOpenGL2',
     'vtkIOExportGL2PS',
     'vtkIOEnSight',
-    'vtkIOHDF',
     'vtkIOERF',
     'vtkIOCityGML',
     'vtkIOChemistry',
     'vtkIOCatalystConduit',
     'vtkIOCONVERGECFD',
     'vtkIOCGNSReader',
+    'vtkIOAvmesh',
     'vtkIOAsynchronous',
     'vtkIOAMR',
     'vtkIOADIOS2',
@@ -167,7 +223,6 @@ __all__ = [
     'vtkInteractionStyle',
     'vtkImagingHybrid',
     'vtkFiltersTensor',
-    'vtkFiltersTemporal',
     'vtkFiltersPython',
     'vtkFiltersProgrammable',
     'vtkFiltersModeling',
@@ -188,6 +243,7 @@ __all__ = [
     'vtkFiltersFlowPaths',
     'vtkFiltersParallelFlowPaths',
     'vtkFiltersParallelDIY2',
+    'vtkFiltersTemporal',
     'vtkFiltersImaging',
     'vtkImagingGeneral',
     'vtkFiltersGeometryPreview',
@@ -195,7 +251,6 @@ __all__ = [
     'vtkFiltersAMR',
     'vtkFiltersParallelMPI',
     'vtkDomainsChemistryOpenGL2',
-    'vtkChartsCore',
     'vtkAcceleratorsVTKmFilters',
     'vtkFiltersReduction',
     'all',
@@ -206,8 +261,48 @@ __all__ = [
     'tk',
     'util',
     'wx',
-]
 
+]
 #------------------------------------------------------------------------------
 # get the version
-__version__ = "9.3.20240617"
+__version__ = "9.5.0"
+
+#------------------------------------------------------------------------------
+# describe import dependencies to properly define Python @override
+MODULE_MAPPER = {
+    "vtkCommonDataModel": [
+        "vtkmodules.util.data_model",
+    ],
+    "vtkCommonExecutionModel": [
+        "vtkmodules.util.execution_model",
+    ],
+}
+LOADED_MODULES = set()
+PENDING_LOADED_MODULES = set()
+
+def register_vtk_module_dependencies(vtk_module_name, *import_names):
+    """Method to call for registering external override on vtkmodule load"""
+    MODULE_MAPPER.setdefault(vtk_module_name, []).extend(import_names)
+
+    # If already loaded let's make sure we import it now
+    if vtk_module_name in LOADED_MODULES:
+        for import_name in import_names:
+            importlib.import_module(import_name)
+
+
+def on_vtk_module_init(module_name):
+    """Automatically called by vtkmodule when they are loaded"""
+    if module_name in LOADED_MODULES:
+        return
+
+    PENDING_LOADED_MODULES.add(module_name)
+
+
+def on_vtk_module_init_completed():
+    pending = list(PENDING_LOADED_MODULES)
+    PENDING_LOADED_MODULES.clear()
+
+    for module_name in pending:
+        LOADED_MODULES.add(module_name)
+        for import_name in MODULE_MAPPER.get(module_name, []):
+            importlib.import_module(import_name)
